@@ -1,4 +1,3 @@
-/* $Id: ipv4_scan.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <string.h>
 #include "ipv4.h"
 
@@ -73,7 +72,7 @@ static void test(const char* start)
   obuf_flush(&outbuf);
 }
 
-void selftest(void)
+MAIN
 {
   test("0");
   test("0.");
