@@ -1,4 +1,3 @@
-/* $Id: tcp4.c 639 2005-11-21 04:43:14Z bruce $ */
 /* net/tcp4 - Create an IPv4 TCP socket
  * Copyright (C) 2004,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -34,3 +33,21 @@ int socket_tcp(void)
 {
   return socket_tcp4();
 }
+
+#ifdef SELFTEST_MAIN
+#include <sys/stat.h>
+#include "selftest.c"
+MAIN
+{
+  int fd;
+  struct stat st;
+  debugsys((fd = socket_tcp4()) >= 0);
+  debugsys(fstat(fd, &st));
+  debugfn((st.st_mode & S_IFMT) == S_IFSOCK);
+}
+#endif
+#ifdef SELFTEST_EXP
+result=1
+result=0
+result=1
+#endif
