@@ -1,4 +1,3 @@
-/* $Id: env_make_array.c 616 2005-08-19 20:11:01Z bruce $ */
 #include <stdlib.h>
 #include <string.h>
 #include "str.h"
@@ -29,7 +28,7 @@ char** envstr_make_array(const struct str* env)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static const str env = {"A=1\0B=2\0C=3\0", 12, 0};
   char** e;
