@@ -12,7 +12,7 @@ void envstr_unset(struct str* env, const char* var)
 
 #ifdef SELFTEST_MAIN
 #include "selftest.c"
-void selftest(void)
+MAIN
 {
   static str env;
   str_copyb(&env, "A=1\0B=2\0C=3\0", 12);
