@@ -1,4 +1,3 @@
-/* $Id: join.c 639 2005-11-21 04:43:14Z bruce $ */
 /* str/join.c - Join two strings together
  * Copyright (C) 2001,2005  Bruce Guenter <bruce@untroubled.org>
  *
@@ -53,3 +52,20 @@ int str_joinb(str* s, char sep, const char* in, unsigned len)
   s->s[s->len] = 0;
   return 1;
 }
+
+#ifdef SELFTEST_MAIN
+#include "selftest.c"
+MAIN 
+{
+  static str s;
+  debugstrfn(str_copys(&s, "one//"), &s);
+  debugstrfn(str_joins(&s, '/', "two"), &s);
+  debugstrfn(str_joins(&s, '/', "//three/"), &s);
+}
+#endif
+
+#ifdef SELFTEST_EXP
+result=1 len=5 size=16 s=one//
+result=1 len=7 size=16 s=one/two
+result=1 len=14 size=16 s=one/two/three/
+#endif
